@@ -19,29 +19,31 @@
  */
 
 #include <glib-object.h>
+#include <glib/gi18n.h>
+#include <stdlib.h>
+#include <stdio.h>
+
+#ifndef USE_TOTEM_PL_PARSER
+#include <unistd.h>
+#include <nautilus-burn.h>
+#else
+#include <totem-disc.h>
+#endif /* USE_TOTEM_PL_PARSER */
+
 #include "sj-metadata.h"
 #include "sj-metadata-marshal.h"
+#include "sj-error.h"
 
 enum {
   METADATA,
   LAST_SIGNAL
 };
 
-static int signals[LAST_SIGNAL] = { 0 };
-
 static void
 sj_metadata_base_init (gpointer g_iface)
 {
   static gboolean initialized = FALSE;
   if (!initialized) {
-    signals[METADATA] = g_signal_new ("metadata",
-                                      G_TYPE_FROM_CLASS (g_iface),
-                                      G_SIGNAL_RUN_LAST,
-                                      G_STRUCT_OFFSET (SjMetadataClass, metadata),
-                                      NULL, NULL,
-                                      metadata_marshal_VOID__POINTER_POINTER,
-                                      G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_POINTER);
-
     /* TODO: make these constructors */
     /* TODO: add nice nick and blurb strings */
     g_object_interface_install_property (g_iface,
@@ -106,17 +108,106 @@ sj_metadata_set_proxy_port (SjMetadata *metadata, const int proxy_port)
   g_object_set (metadata, "proxy-port", proxy_port, NULL);
 }
 
-void
-sj_metadata_list_albums (SjMetadata *metadata, GError **error)
+GList *
+sj_metadata_list_albums (SjMetadata *metadata, char **url, GError **error)
 {
-  SJ_METADATA_GET_CLASS (metadata)->list_albums (metadata, error);
+  return SJ_METADATA_GET_CLASS (metadata)->list_albums (metadata, url, error);
 }
 
 char *
-sj_metadata_get_submit_url (SjMetadata *metadata)
+sj_metadata_helper_scan_disc_number (const char *album_title, int *disc_number)
 {
-  if (SJ_METADATA_GET_CLASS (metadata)->get_submit_url)
-    return SJ_METADATA_GET_CLASS (metadata)->get_submit_url (metadata);
-  else
-    return NULL;
+  GRegex *disc_regex;
+  GMatchInfo *info;
+  char *new_title;
+  int num;
+
+  disc_regex = g_regex_new (".+( \\(disc (\\d+).*)", 0, 0, NULL);
+  new_title = NULL;
+  *disc_number = 0;
+
+  if (g_regex_match (disc_regex, album_title, 0, &info)) {
+    int pos = 0;
+    char *s;
+
+    g_match_info_fetch_pos (info, 1, &pos, NULL);
+    if (pos) {
+      new_title = g_strndup (album_title, pos);
+    }
+
+    s = g_match_info_fetch (info, 2);
+    num = atoi (s);
+    *disc_number = num;
+    g_free (s);
+  }
+
+  g_match_info_free (info);
+  g_regex_unref (disc_regex);
+
+  return new_title;
 }
+
+GDate *
+sj_metadata_helper_scan_date (const char *date)
+{
+  int matched, year=1, month=1, day=1;
+  matched = sscanf(date, "%u-%u-%u", &year, &month, &day);
+  if (matched >= 1) {
+    return g_date_new_dmy ((day == 0) ? 1 : day, (month == 0) ? 1 : month, year);
+  }
+
+  return NULL;
+}
+
+gboolean
+sj_metadata_helper_check_media (const char *cdrom, GError **error)
+{
+#ifndef USE_TOTEM_PL_PARSER
+  NautilusBurnMediaType type;
+  NautilusBurnDriveMonitor *monitor;
+  NautilusBurnDrive *drive;
+
+  if (! nautilus_burn_initialized ()) {
+    nautilus_burn_init ();
+  }
+  monitor = nautilus_burn_get_drive_monitor ();
+  drive = nautilus_burn_drive_monitor_get_drive_for_device (monitor, cdrom);
+  if (drive == NULL) {
+    return FALSE;
+  }
+  type = nautilus_burn_drive_get_media_type (drive);
+  nautilus_burn_drive_unref (drive);
+
+  if (type == NAUTILUS_BURN_MEDIA_TYPE_ERROR) {
+    char *msg;
+    SjError err;
+
+    if (access (cdrom, W_OK) == 0) {
+      msg = g_strdup_printf (_("Device '%s' does not contain any media"), cdrom);
+      err = SJ_ERROR_CD_NO_MEDIA;
+    } else {
+      msg = g_strdup_printf (_("Device '%s' could not be opened. Check the access permissions on the device."), cdrom);
+      err = SJ_ERROR_CD_PERMISSION_ERROR;
+    }
+    g_set_error (error, SJ_ERROR, err, _("Cannot read CD: %s"), msg);
+    g_free (msg);
+
+    return FALSE;
+  }
+#else
+  TotemDiscMediaType type;
+  GError *totem_error = NULL;
+
+  type = totem_cd_detect_type (cdrom, &totem_error);
+
+  if (totem_error != NULL) {
+    g_set_error (error, SJ_ERROR, SJ_ERROR_CD_NO_MEDIA, _("Cannot read CD: %s"), totem_error->message);
+    g_error_free (totem_error);
+
+    return FALSE;
+  }
+#endif /* !USE_TOTEM_PL_PARSER */
+
+  return TRUE;
+}
+
